==> kooplearn-0.2.0.dev2.tar.gz: kooplearn-0.2.0.dev2/README.md <==
<p align = "left">
  <img src="logo.svg" alt="SVG Image" style="width:50%;"/>
</p>

# `kooplearn`: Learn Koopman and transfer operators of Dynamical Systems

`kooplearn` is a Python library designed for learning Koopman operators or transfer operators associated with dynamical systems. It provides an array of algorithms for model training and analysis, enabling users to perform forecasting, spectral decomposition, and modal decomposition based on the learned operator.

Please note that `kooplearn` is currently under active development, and while we are continuously adding new features and improvements, some parts of the library might still be a work in progress.

## Features

- Implement different algorithms to learn Koopman or transfer operators for dynamical systems.
- Perform forecasting using the learned operators.
- Conduct spectral decomposition of the learned operator.
- Perform modal decomposition for further analysis.
  
## Installation

`kooplearn` can be locally installed in editable mode for easy development and experimentation. Follow the steps below to install `kooplearn` using pip:

1. Clone the repository:

   ```bash
   git clone https://github.com/CSML-IIT-UCL/kooplearn.git
   ```
2. Navigate to the library's directory:

    ```bash
    cd kooplearn
    ```
3. Install the library in editable mode using pip:

    ```bash
    pip install -e .
    ```
## Contributing

We welcome contributions from the community! If you're interested in contributing to `kooplearn`, please follow these steps:

1. Fork the repository on GitHub.
2. Clone your forked repository to your local machine.
3. Create a new branch for your feature or bug fix: `git checkout -b feature/your-feature-name` or `git checkout -b bugfix/issue-number`.
4. Make your changes and commit them with descriptive commit messages.
5. Push your changes to your forked repository.
6. Create a pull request from your branch to the `main` branch of the original repository.
7. Provide a clear title and description for your pull request, including any relevant information about the changes you've made.

We appreciate your contributions and will review your pull request as soon as possible. Thank you for helping improve `kooplearn`!

## License

This project is licensed under the [MIT License](LICENSE).

---

We hope you find `kooplearn` useful for your dynamical systems analysis. If you encounter any issues or have suggestions for improvements, please don't hesitate to [raise an issue](https://github.com/CSML-IIT-UCL/kooplearn/issues). Happy coding!

==> kooplearn-1.0.2.tar.gz: kooplearn-1.0.2/README.md <==
<p align = "left">
  <img src="logo.svg" alt="SVG Image" style="width:50%;"/>
</p>

# `kooplearn`: Learn Koopman and transfer operators of Dynamical Systems

`kooplearn` is a Python library designed for learning Koopman operators or transfer operators associated with dynamical systems. It provides an array of algorithms for model training and analysis, enabling users to perform forecasting, spectral decomposition, and modal decomposition based on the learned operator.

Please note that `kooplearn` is currently under active development, and while we are continuously adding new features and improvements, some parts of the library might still be a work in progress.

## Features

- Implement different algorithms to learn Koopman or transfer operators for dynamical systems.
- Perform forecasting using the learned operators.
- Conduct spectral decomposition of the learned operator.
- Perform modal decomposition for further analysis.
  
## Installation
```bash
pip install kooplearn
# Or to install the latest version of kooplearn from git:
pip install --upgrade git+https://github.com/CSML-IIT-UCL/kooplearn.git
```
## Contributing

We welcome contributions from the community! If you're interested in contributing to `kooplearn`, please follow these steps:

1. Fork the repository on GitHub.
2. Clone your forked repository to your local machine.
3. Create a new branch for your feature or bug fix: `git checkout -b feature/your-feature-name` or `git checkout -b bugfix/issue-number`.
4. Make your changes and commit them with descriptive commit messages.
5. Push your changes to your forked repository.
6. Create a pull request from your branch to the `main` branch of the original repository.
7. Provide a clear title and description for your pull request, including any relevant information about the changes you've made.

We appreciate your contributions and will review your pull request as soon as possible. Thank you for helping improve `kooplearn`!

## License

This project is licensed under the [MIT License](LICENSE).

---

We hope you find `kooplearn` useful for your dynamical systems analysis. If you encounter any issues or have suggestions for improvements, please don't hesitate to [raise an issue](https://github.com/CSML-IIT-UCL/kooplearn/issues). Happy coding!
